%define MOD_PATH linux-git.us.oracle.com/OLCNE
%define PROTOC_URL https://github.com/protocolbuffers/protobuf/releases/download/v3.8.0/protoc-3.8.0-linux-x86_64.zip
%define PROTOC_SHA 717903f32653f07cd895cfe89ca18ff4ca35f825afa7fe17bcb5cb13bf628be0
%define PROTOC_GEN_GO_URL github.com/golang/protobuf/protoc-gen-go
%define PROTOC_GEN_GO_TAG v1.3.2

%global debug_package %{nil}

Name: olcne
Version: 1.0.1
Release: 2%{?dist}
Vendor: Oracle America
Summary: Oracle Linux Cloud Native Environment Platform API Server, Platform Agent and Platform Command Line Interface (CLI).
License: UPL
Group: Development/Tools

Source0: %{name}-%{version}.tar.bz2
BuildRequires: golang >= 1.13.1
BuildRequires: coreutils
BuildRequires: unzip

Requires: olcnectl = %{version}
Requires: olcne-agent = %{version}
Requires: olcne-api-server = %{version}

%package -n olcnectl
Summary: Oracle Linux Cloud Native Environment Platform Command Line Interface (CLI)

%package -n olcne-agent
Summary: Oracle Linux Cloud Native Environment Platform Agent
Requires: etcd >= 3.3.0
Requires: jq
Requires: podman

%package -n olcne-api-server
Summary: Oracle Linux Cloud Native Environment Platform API Server
Requires: kubectl >= 1.14.0, kubectl <= 1.14.99

%package -n olcne-testing
Summary: Testing utilities for Oracle Linux Cloud Native Environment

%package -n olcne-utils
Summary: Helper utilities for Oracle Linux Cloud Native Environment

%package -n olcne-nginx
Summary: NGINX-based load balancer used by the Kubernetes module for Oracle Linux Cloud Native Environment
Requires: podman

%description
This package contains the Oracle Linux Cloud Native Environment Platform API Server, Platform Agent and Platform Command Line Interface (CLI). These unified management tools simplify the installation and day-to-day management of Oracle Linux Cloud Native Environment, and provide extensibility to support new functionality.

%description -n olcnectl
Oracle Linux Cloud Native Environment Platform Command Line Interface (CLI).

%description -n olcne-agent
Cluster-side agent that handles work on behalf of the Oracle Linux Cloud Native Environment Platform API Server.

%description -n olcne-api-server
The Oracle Linux Cloud Native Environment Platform API Server.

%description -n olcne-testing
Utility scripts used during Oracle Linux Cloud Native Environment development to facilitate testing.

%description -n olcne-utils
+Utility scripts to aid in the deployment and management of the Oracle Linux Cloud Native Environment.

%description -n olcne-nginx
An NGINX build tailored specifically for acting as a load balancer for the master nodes deployed by the Kubernetes module for Oracle Linux Cloud Native Environment.

%prep
%setup -q

%build

# setup build environment
export GOPATH=$HOME/rpmbuild/BUILD/go
export GO111MODULE=on
mkdir -p $GOPATH/bin
mkdir -p $GOPATH/src/%{MOD_PATH}
ln -s `pwd` $GOPATH/src/%{MOD_PATH}/olcne-lib
pushd $GOPATH/src/%{MOD_PATH}/olcne-lib

go get -d -u %{PROTOC_GEN_GO_URL}
cd "$(go env GOPATH)"/src/github.com/golang/protobuf && git checkout %{PROTOC_GEN_GO_TAG}
go install github.com/golang/protobuf/protoc-gen-go

curl -L %{PROTOC_URL} > protoc.zip
PROTOC_SHA_REAL=`sha256sum protoc.zip | awk '{ print $1 }'`
[ "$PROTOC_SHA_REAL" != "%{PROTOC_SHA}" ] && exit 1

unzip -d / protoc.zip

export PATH=$GOPATH/bin:$PATH

# do the build
make all

popd

%install
make install DESTDIR=%{buildroot}
install -m 755 -d %{buildroot}/var/log/olcne
install -m 755 -d %{buildroot}/etc/olcne
install -m 755 -d %{buildroot}/etc/olcne-nginx
install -m 755 -d %{buildroot}/etc/olcne/certificates
cp scripts/bootstrap-vault.sh %{buildroot}/etc/olcne/bootstrap-vault.sh
cp scripts/gen-certs-helper.sh %{buildroot}/etc/olcne/gen-certs-helper.sh
cp scripts/bootstrap-olcne.sh %{buildroot}/etc/olcne/bootstrap-olcne.sh
cp scripts/registry-image-helper.sh %{buildroot}/usr/bin/registry-image-helper.sh
cp scripts/start_olcne_nginx %{buildroot}/usr/libexec/start_olcne_nginx
cp scripts/pull_olcne_nginx %{buildroot}/usr/libexec/pull_olcne_nginx
install -m 755 -d %{buildroot}/usr/share/doc/%{name}-%{version}/nginx
cp docs/container-images/nginx.Dockerfile %{buildroot}/usr/share/doc/%{name}-%{version}/nginx/Dockerfile

%files

%files -n olcnectl
%license LICENSE THIRD_PARTY_LICENSES.txt

/usr/bin/olcnectl

# Setup olcne user for agent binary root access
%pre -n olcne-agent
getent group olcne >/dev/null || \
    groupadd -r olcne
getent passwd olcne >/dev/null || \
    useradd -r -g olcne \
    -c "User created to manage olcne privileged cmds" olcne
exit 0

%pre -n olcne-api-server
getent group olcne >/dev/null || \
    groupadd -r olcne
getent passwd olcne >/dev/null || \
    useradd -r -g olcne \
    -c "User created to manage olcne privileged cmds" olcne
exit 0


%post -n olcne-agent
systemctl daemon-reload

%post -n olcne-api-server
systemctl daemon-reload

%post -n olcne-nginx
systemctl daemon-reload

%preun -n olcne-agent
if [ $1 == 0 ]; then
  systemctl unmask olcne-agent.service
  systemctl stop olcne-agent.service
  systemctl disable olcne-agent.service
fi

%preun -n olcne-api-server
if [ $1 == 0 ]; then
  systemctl unmask olcne-api-server.service
  systemctl stop olcne-api-server.service
  systemctl disable olcne-api-server.service
fi

%preun -n olcne-nginx
if [ $1 == 0 ]; then
  systemctl unmask olcne-nginx.service
  systemctl stop olcne-nginx.service
  systemctl disable olcne-nginx.service
fi

%postun -n olcne-agent
if [ $1 == 0 ]; then
  systemctl daemon-reload
  systemctl reset-failed
fi

%postun -n olcne-api-server
if [ $1 == 0 ]; then
  systemctl daemon-reload
  systemctl reset-failed
fi

%files -n olcne-agent
%attr(-,olcne,olcne) /usr/libexec/olcne-agent
%license LICENSE THIRD_PARTY_LICENSES.txt
/usr/libexec/olcne-agent
/usr/libexec/syscheck
/usr/libexec/kubeman
%{_usr}/lib/systemd/system/olcne-agent.service
/etc/olcne/scripts/*
%attr(0755, root, root) /etc/olcne/scripts/*
/etc/sudoers.d/olcne
%dir %attr(0755, olcne, olcne) /var/log/olcne
%dir %attr(0755, olcne, olcne) /etc/olcne/certificates
%dir %attr(0750, olcne, olcne) /var/olcne/scratch

%files -n olcne-api-server
%license LICENSE THIRD_PARTY_LICENSES.txt
/usr/libexec/olcne-api-server
/etc/olcne/modules/kubernetes/1.0.0/kubernetes.yaml
/etc/olcne/modules/node/1.0.0/node.yaml
%{_usr}/lib/systemd/system/olcne-api-server.service
%dir %attr(0755, olcne, olcne) /var/olcne
%dir %attr(0750, olcne, olcne) /var/olcne/backups
%dir %attr(0755, olcne, olcne) /etc/olcne/certificates

%files -n olcne-nginx
%license LICENSE
/usr/libexec/start_olcne_nginx
/usr/libexec/pull_olcne_nginx
%{_usr}/lib/systemd/system/olcne-nginx.service
%dir %attr(0755, root, root) /etc/olcne-nginx
/usr/share/doc/%{name}-%{version}/nginx/Dockerfile

%files -n olcne-testing
%license LICENSE THIRD_PARTY_LICENSES.txt
%dir /etc/olcne/testing/configs/certificates
/etc/systemd/system/olcne-agent.service.d/10-auth.conf
/etc/systemd/system/olcne-api-server.service.d/10-auth.conf

%files -n olcne-utils
%license LICENSE
/etc/olcne/bootstrap-vault.sh
/etc/olcne/gen-certs-helper.sh
/etc/olcne/bootstrap-olcne.sh
/usr/bin/registry-image-helper.sh

%changelog
* Fri Feb 07 2020 Daniel Krasinski <daniel.krasinski@oracle.com> 1.0.1-1
- Added support for updating Kubernetes clusters

* Fri Nov 15 2019 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> 1.0.0-3
- Updated summary and description fields to match the Oracle Linux Cloud Native Environment naming conventions.

* Thu Nov 07 2019 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> 1.0.0-2
- Patch for shorter package Summary

* Fri Oct 18 2019 Daniel Krasinski <daniel.krasinski@oracle.com> 1.0.0-1
- Initial Release
